==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFMultiVectorOperatorDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFMULTIVECTOROPERATOR_DECL_HPP
#define TSFMULTIVECTOROPERATOR_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFRowAccessibleOp.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "SundanceHandleable.hpp"
#include "Teuchos_RefCountPtr.hpp"
#include "TSFVectorDecl.hpp"

namespace TSFExtended
{
/** 
 * A MultiVectorOperator is a linear operator whose
 * rows or columns are represented as a multivector 
 */
template <class Scalar> 
class MultiVectorOperator 
  : public OpWithBackwardsCompatibleApply<Scalar>,
    public RowAccessibleOp<Scalar>
{
public:

  /**
   * Construct from an array of vectors and a specifier for the 
   * domain space. 
   */
  MultiVectorOperator(const Teuchos::Array<Vector<Scalar> >& cols,
    const VectorSpace<Scalar>& domain);

  /** Virtual dtor */
  virtual ~MultiVectorOperator(){;}


  /** 
   * Apply does an element-by-element multiply between the input 
   * vector, x, and the diagonal values.
   */
  virtual void generalApply(
    const Thyra::ETransp            M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>          *y,
    const Scalar            alpha = 1.0,
    const Scalar            beta  = 0.0
    ) const ;


  /** Return the domain of the operator */
  RefCountPtr< const Thyra::VectorSpaceBase<Scalar> > domain() const ;


  /** Return the range of the operator */
  RefCountPtr< const Thyra::VectorSpaceBase<Scalar> > range() const ;



  /** Return the kth row  */
  void getRow(const int& k, 
    Teuchos::Array<int>& indices, 
    Teuchos::Array<Scalar>& values) const ;

private:

  Teuchos::Array<Vector<Scalar> > cols_;
  VectorSpace<Scalar> domain_;
  VectorSpace<Scalar> range_;
};

/** \relates MultiVectorOperator */
template <class Scalar> 
LinearOperator<Scalar> multiVectorOperator(
  const Teuchos::Array<Vector<Scalar> >& cols,
  const VectorSpace<Scalar>& domain);
}

#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-solvers/Operators/TSFMultiVectorOperatorDecl.hpp <==
/* @HEADER@ */
/* ***********************************************************************
// 
//           TSFExtended: Trilinos Solver Framework Extended
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// **********************************************************************/
 /* @HEADER@ */

#ifndef TSFMULTIVECTOROPERATOR_DECL_HPP
#define TSFMULTIVECTOROPERATOR_DECL_HPP

#include "SundanceDefs.hpp"
#include "TSFRowAccessibleOp.hpp"
#include "TSFOpWithBackwardsCompatibleApply.hpp"
#include "TSFLinearOperatorDecl.hpp"
#include "SundanceHandleable.hpp"
#include "Teuchos_RefCountPtr.hpp"
#include "TSFVectorDecl.hpp"

namespace TSFExtended
{
/** 
 * A MultiVectorOperator is a linear operator whose
 * rows or columns are represented as a multivector 
 */
template <class Scalar> 
class MultiVectorOperator 
  : public OpWithBackwardsCompatibleApply<Scalar>,
    public RowAccessibleOp<Scalar>
{
public:

  /**
   * Construct from an array of vectors and a specifier for the 
   * domain space. 
   */
  MultiVectorOperator(const Teuchos::Array<Vector<Scalar> >& cols,
    const VectorSpace<Scalar>& domain);

  /** Virtual dtor */
  virtual ~MultiVectorOperator(){;}


  /** 
   * Apply does an element-by-element multiply between the input 
   * vector, x, and the diagonal values.
   */
  virtual void generalApply(
    const Thyra::EOpTransp            M_trans,
    const Thyra::VectorBase<Scalar>    &x,
    Thyra::VectorBase<Scalar>          *y,
    const Scalar            alpha = 1.0,
    const Scalar            beta  = 0.0
    ) const ;


  /** Return the domain of the operator */
  RCP< const Thyra::VectorSpaceBase<Scalar> > domain() const ;


  /** Return the range of the operator */
  RCP< const Thyra::VectorSpaceBase<Scalar> > range() const ;



  /** Return the kth row  */
  void getRow(const int& k, 
    Teuchos::Array<int>& indices, 
    Teuchos::Array<Scalar>& values) const ;

private:

  Teuchos::Array<Vector<Scalar> > cols_;
  VectorSpace<Scalar> domain_;
  VectorSpace<Scalar> range_;
};

/** \relates MultiVectorOperator */
template <class Scalar> 
LinearOperator<Scalar> multiVectorOperator(
  const Teuchos::Array<Vector<Scalar> >& cols,
  const VectorSpace<Scalar>& domain);
}

#endif
